@@ -20,7 +20,7 @@
 #define _BABL_MACROS_H
 
 #if !defined(BABL_INSIDE_BABL_H) && !defined(BABL_IS_BEING_COMPILED)
-#error "babl-version.h must not be included directly, include babl.h instead."
+#error "babl-macros.h must not be included directly, include babl.h instead."
 #endif
 
 
